@@ -1,6 +1,6 @@
 /*
- * security.c: Routines to aid secure uid operations 
- *  
+ * security.c: Routines to aid secure uid operations
+ *
  * Copyright (C) 1994, 1995 Graeme W. Wilford. (Wilf.)
  * Copyright (C) 2001, 2003, 2004, 2007, 2010, 2011 Colin Watson.
  *
@@ -20,7 +20,7 @@
  * along with man-db; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * Mon Aug  8 20:35:30 BST 1994  Wilf. (G.Wilford@ee.surrey.ac.uk) 
+ * Mon Aug  8 20:35:30 BST 1994  Wilf. (G.Wilford@ee.surrey.ac.uk)
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,15 +35,18 @@
 #include <errno.h>
 #include <sys/types.h>
 
+#include "attribute.h"
+#include "error.h"
 #include "gettext.h"
 #define _(String) gettext (String)
 
 #include "manconfig.h"
 
-#include "error.h"
-#include "cleanup.h"
 #include "pipeline.h"
 
+#include "cleanup.h"
+#include "debug.h"
+#include "fatal.h"
 #include "security.h"
 
 #ifdef MAN_OWNER
@@ -76,7 +79,7 @@ static int priv_drop_count = 0;
 
 static void gripe_set_euid (void)
 {
-	error (FATAL, errno, _("can't set effective uid"));
+	fatal (errno, _("can't set effective uid"));
 }
 
 #endif /* MAN_OWNER */
@@ -95,7 +98,7 @@ void init_security (void)
 #endif /* MAN_OWNER */
 }
 
-bool _GL_ATTRIBUTE_PURE running_setuid (void)
+bool ATTRIBUTE_PURE running_setuid (void)
 {
 #ifdef MAN_OWNER
 	return ruid != euid;
@@ -122,8 +125,8 @@ struct passwd *get_man_owner (void)
 }
 #endif /* MAN_OWNER */
 
-/* 
- * function to gain user privs by either (a) dropping effective privs 
+/*
+ * function to gain user privs by either (a) dropping effective privs
  * completely (saved ids) or (b) reversing euid w/ uid.
  * Ignore if superuser.
  */
@@ -143,7 +146,7 @@ void drop_effective_privs (void)
 #endif /* MAN_OWNER */
 }
 
-/* 
+/*
  * function to (re)gain setuid privs by (a) setting euid from suid or (b)
  * (re)reversing uid w/ euid. Ignore if superuser.
  */
@@ -169,7 +172,7 @@ void regain_effective_privs (void)
 }
 
 /* Pipeline command pre-exec hook to permanently drop privileges. */
-void drop_privs (void *data _GL_UNUSED)
+void drop_privs (void *data MAYBE_UNUSED)
 {
 #ifdef MAN_OWNER
 	if (idpriv_drop ())
