@@ -35,6 +35,7 @@
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#include <assert.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -44,16 +45,21 @@
 #include <unistd.h>
 #include <locale.h>
 
+#include "attribute.h"
 #include "stat-time.h"
 #include "timespec.h"
+#include "xalloc.h"
+#include "xstrndup.h"
 #include "xvasprintf.h"
 
 #include "gettext.h"
 
 #include "manconfig.h"
 
+#include "debug.h"
 #include "error.h"
 #include "pipeline.h"
+#include "util.h"
 
 /*
  * Does file a have a different timestamp to file b?
@@ -163,6 +169,7 @@ int remove_directory (const char *directory, int recurse)
 		if (STREQ (entry->d_name, ".") || STREQ (entry->d_name, ".."))
 			continue;
 		path = xasprintf ("%s/%s", directory, entry->d_name);
+		assert (path);
 		if (stat (path, &st) == -1) {
 			free (path);
 			closedir (handle);
@@ -193,7 +200,7 @@ int remove_directory (const char *directory, int recurse)
 /* Returns an allocated copy of s, with leading and trailing spaces
  * removed.
  */
-char * _GL_ATTRIBUTE_MALLOC trim_spaces (const char *s)
+char * ATTRIBUTE_MALLOC trim_spaces (const char *s)
 {
 	int length;
 	while (*s == ' ')
@@ -211,7 +218,7 @@ char *lang_dir (const char *filename)
 	const char *sm;	/* the second "/man?/" dir */
 
 	ld = xstrdup ("");
-	if (!filename) 
+	if (!filename)
 		return ld;
 
 	/* Check whether filename is in a man page hierarchy. */
